@@ -549,6 +549,18 @@ nsMsgMailNewsUrl::CloneIgnoringRef(nsIURI** result)
   return NS_OK;
 }
 
+NS_IMETHODIMP
+nsMsgMailNewsUrl::GetSpecIgnoringRef(nsACString &result)
+{
+  return m_baseURL->GetSpecIgnoringRef(result);
+}
+
+NS_IMETHODIMP
+nsMsgMailNewsUrl::GetHasRef(PRBool *result)
+{
+  return m_baseURL->GetHasRef(result);
+}
+
 NS_IMETHODIMP nsMsgMailNewsUrl::SchemeIs(const char *aScheme, PRBool *_retval)
 {
   return m_baseURL->SchemeIs(aScheme, _retval);
@@ -663,16 +675,6 @@ NS_IMETHODIMP nsMsgMailNewsUrl::SetFileName(const nsACString &aFileName)
   return NS_OK;
 }
 
-NS_IMETHODIMP nsMsgMailNewsUrl::GetParam(nsACString &aParam)
-{
-  return m_baseURL->GetParam(aParam);
-}
-
-NS_IMETHODIMP nsMsgMailNewsUrl::SetParam(const nsACString &aParam)
-{
-  return m_baseURL->SetParam(aParam);
-}
-
 NS_IMETHODIMP nsMsgMailNewsUrl::GetQuery(nsACString &aQuery)
 {
   return m_baseURL->GetQuery(aQuery);
