@@ -168,6 +168,10 @@ NS_IMETHODIMP nsEudoraEditor::GetIsDocumentEditable(PRBool *aIsDocumentEditable)
   return NS_ERROR_NOT_IMPLEMENTED;
 }
 
+NS_IMETHODIMP nsEudoraEditor::GetIsSelectionEditable(PRBool *aIsSelectionEditable)
+{
+  return NS_ERROR_NOT_IMPLEMENTED;
+}
 
 // readonly attribute nsIDOMDocument document
 NS_IMETHODIMP nsEudoraEditor::GetDocument(nsIDOMDocument * *aDocument)
@@ -949,6 +953,11 @@ NS_IMETHODIMP nsEudoraHTMLImageElement::GetParentNode(nsIDOMNode * *aParentNode)
   return NS_ERROR_NOT_IMPLEMENTED;
 }
 
+// readonly attribute nsIDOMNode parentElement
+NS_IMETHODIMP nsEudoraHTMLImageElement::GetParentElement(nsIDOMElement * *aParentElement)
+{
+  return NS_ERROR_NOT_IMPLEMENTED;
+}
 
 // readonly attribute nsIDOMNodeList childNodes
 NS_IMETHODIMP nsEudoraHTMLImageElement::GetChildNodes(nsIDOMNodeList * *aChildNodes)
@@ -1268,6 +1277,11 @@ NS_IMETHODIMP nsEudoraHTMLImageElement::SetAccessKey(const nsAString &aAccessKey
   return NS_ERROR_NOT_IMPLEMENTED;
 }
 
+NS_IMETHODIMP nsEudoraHTMLImageElement::GetAccessKeyLabel(nsAString &aAccessKey)
+{
+  return NS_ERROR_NOT_IMPLEMENTED;
+}
+
 NS_IMETHODIMP nsEudoraHTMLImageElement::Blur()
 {
   return NS_ERROR_NOT_IMPLEMENTED;
@@ -1302,12 +1316,21 @@ NS_IMETHODIMP nsEudoraHTMLImageElement::GetAlign(nsAString & aAlign)
   return NS_ERROR_NOT_IMPLEMENTED;
 }
 
-
 NS_IMETHODIMP nsEudoraHTMLImageElement::SetAlign(const nsAString & aAlign)
 {
   return NS_ERROR_NOT_IMPLEMENTED;
 }
 
+// attribute DOMString crossOrigin
+NS_IMETHODIMP nsEudoraHTMLImageElement::GetCrossOrigin(nsAString & aCrossOrigin)
+{
+  return NS_ERROR_NOT_IMPLEMENTED;
+}
+
+NS_IMETHODIMP nsEudoraHTMLImageElement::SetCrossOrigin(const nsAString & aCrossOrigin)
+{
+  return NS_ERROR_NOT_IMPLEMENTED;
+}
 
 // attribute DOMString alt
 NS_IMETHODIMP nsEudoraHTMLImageElement::GetAlt(nsAString & aAlt)
@@ -1338,13 +1361,13 @@ NS_IMETHODIMP nsEudoraHTMLImageElement::GetComplete(PRBool *aResult)
 }
 
 // readonly attribute long naturalWidth
-NS_IMETHODIMP nsEudoraHTMLImageElement::GetNaturalWidth(PRInt32 *aResult)
+NS_IMETHODIMP nsEudoraHTMLImageElement::GetNaturalWidth(PRUint32 *aResult)
 {
   return NS_ERROR_NOT_IMPLEMENTED;
 }
 
 // readonly attribute long naturalHeight
-NS_IMETHODIMP nsEudoraHTMLImageElement::GetNaturalHeight(PRInt32 *aResult)
+NS_IMETHODIMP nsEudoraHTMLImageElement::GetNaturalHeight(PRUint32 *aResult)
 {
   return NS_ERROR_NOT_IMPLEMENTED;
 }
@@ -1363,13 +1386,13 @@ NS_IMETHODIMP nsEudoraHTMLImageElement::SetBorder(const nsAString & aBorder)
 
 
 // attribute long height
-NS_IMETHODIMP nsEudoraHTMLImageElement::GetHeight(PRInt32 *aHeight)
+NS_IMETHODIMP nsEudoraHTMLImageElement::GetHeight(PRUint32 *aHeight)
 {
   return NS_ERROR_NOT_IMPLEMENTED;
 }
 
 
-NS_IMETHODIMP nsEudoraHTMLImageElement::SetHeight(PRInt32 aHeight)
+NS_IMETHODIMP nsEudoraHTMLImageElement::SetHeight(PRUint32 aHeight)
 {
   return NS_ERROR_NOT_IMPLEMENTED;
 }
@@ -1462,13 +1485,13 @@ NS_IMETHODIMP nsEudoraHTMLImageElement::SetVspace(PRInt32 aVspace)
 
 
 // attribute long width
-NS_IMETHODIMP nsEudoraHTMLImageElement::GetWidth(PRInt32 *aWidth)
+NS_IMETHODIMP nsEudoraHTMLImageElement::GetWidth(PRUint32 *aWidth)
 {
   return NS_ERROR_NOT_IMPLEMENTED;
 }
 
 
-NS_IMETHODIMP nsEudoraHTMLImageElement::SetWidth(PRInt32 aWidth)
+NS_IMETHODIMP nsEudoraHTMLImageElement::SetWidth(PRUint32 aWidth)
 {
   return NS_ERROR_NOT_IMPLEMENTED;
 }
@@ -1498,6 +1521,11 @@ NS_IMETHODIMP nsEudoraHTMLImageElement::IsSameNode(nsIDOMNode *other, PRBool *_r
   return NS_ERROR_NOT_IMPLEMENTED;
 }
 
+NS_IMETHODIMP nsEudoraHTMLImageElement::Contains(nsIDOMNode* aOther, PRBool* aReturn)
+{
+  return NS_ERROR_NOT_IMPLEMENTED;
+}
+
 NS_IMETHODIMP nsEudoraHTMLImageElement::LookupPrefix(const nsAString & namespaceURI, nsAString & _retval NS_OUTPARAM)
 {
   return NS_ERROR_NOT_IMPLEMENTED;
